@@ -2,13 +2,13 @@ package LCFG::Build::Tool::DevPack;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: DevPack.pm.in 3446 2009-03-11 13:26:13Z squinney@INF.ED.AC.UK $
+# $Id: DevPack.pm.in 5773 2010-01-18 18:09:28Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/DevPack.pm.in,v $
-# $Revision: 3446 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_0_56/lib/LCFG/Build/Tool/DevPack.pm.in $
-# $Date: 2009-03-11 13:26:13 +0000 (Wed, 11 Mar 2009) $
+# $Revision: 5773 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_0_58/lib/LCFG/Build/Tool/DevPack.pm.in $
+# $Date: 2010-01-18 18:09:28 +0000 (Mon, 18 Jan 2010) $
 
-our $VERSION = '0.0.56';
+our $VERSION = '0.0.58';
 
 use File::Path ();
 use File::Spec ();
@@ -50,7 +50,7 @@ sub abstract {
     return q{Package the development source tree};
 }
 
-sub run {
+sub execute {
     my ($self) = @_;
 
     my ( $spec, $vcs ) = ( $self->spec, $self->vcs );
@@ -157,17 +157,17 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::DevPack version 0.0.56
+    This documentation refers to LCFG::Build::Tool::DevPack version 0.0.58
 
 =head1 SYNOPSIS
 
     my $tool = LCFG::Build::Tool::DevPack->new( dir => '.' );
 
-    $tool->run;
+    $tool->execute;
 
     my $tool2 = LCFG::Build::Tool::DevPack->new_with_options();
 
-    $tool2->run;
+    $tool2->execute;
 
 =head1 DESCRIPTION
 
@@ -284,7 +284,7 @@ L<LCFG::Build::VCS> for full details.
 
 =over 4
 
-=item run
+=item execute
 
 This uses the relevant L<LCFG::Build::VCS> module to export the
 version of the project in your development tree and packages it into a
